==> socnetv_0.90.orig.tar.gz: socnetv-0.90/src/edgeweight.h <==
/***************************************************************************
 SocNetV: Social Networks Visualizer 
 version: 0.90
 Written in Qt 4.4 with KDevelop   
 
                         edgeweight.h  -  description
                             -------------------
    copyright            : (C) 2005-2010 by Dimitris B. Kalamaras
    email                : dimitris.kalamaras@gmail.com
 ***************************************************************************/

/*******************************************************************************
*     This program is free software: you can redistribute it and/or modify     *
*     it under the terms of the GNU General Public License as published by     *
*     the Free Software Foundation, either version 3 of the License, or        *
*     (at your option) any later version.                                      *
*                                                                              *
*     This program is distributed in the hope that it will be useful,          *
*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
*     GNU General Public License for more details.                             *
*                                                                               *
*     You should have received a copy of the GNU General Public License        *
*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
********************************************************************************/



#ifndef EDGEWEIGHT_H
#define EDGEWEIGHT_H


#include <QGraphicsTextItem>
#include "edge.h"

static const int TypeEdgeWeight = QGraphicsItem::UserType+5;

class EdgeWeight: public QGraphicsTextItem
{
public:
    	EdgeWeight(Edge * , int, QString, QGraphicsScene * );
	void removeRefs();
	void move(double x, double y);

	enum { Type = UserType + 5 };
	int type() const { return Type; }

	~EdgeWeight();
private:
};

#endif

==> socnetv_1.4+dfsg.orig.tar.gz: socnetv-1.4/src/edgeweight.h <==
/***************************************************************************
 SocNetV: Social Networks Visualizer 
 version: 1.4
 Written in Qt
                         edgeweight.h  -  description
                             -------------------
    copyright            : (C) 2005-2014 by Dimitris B. Kalamaras
    email                : dimitris.kalamaras@gmail.com
 ***************************************************************************/

/*******************************************************************************
*     This program is free software: you can redistribute it and/or modify     *
*     it under the terms of the GNU General Public License as published by     *
*     the Free Software Foundation, either version 3 of the License, or        *
*     (at your option) any later version.                                      *
*                                                                              *
*     This program is distributed in the hope that it will be useful,          *
*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
*     GNU General Public License for more details.                             *
*                                                                               *
*     You should have received a copy of the GNU General Public License        *
*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
********************************************************************************/



#ifndef EDGEWEIGHT_H
#define EDGEWEIGHT_H


#include <QGraphicsTextItem>
class Edge;

static const int TypeEdgeWeight = QGraphicsItem::UserType+5;

class EdgeWeight: public QGraphicsTextItem
{
public:
    EdgeWeight(Edge * , int, QString);
	void removeRefs();
	void move(double x, double y);

	enum { Type = UserType + 5 };
	int type() const { return Type; }

	~EdgeWeight();
private:
};

#endif
